@@ -45,7 +45,7 @@ Run 'colima template' to set the default configurations or 'colima start --edit'
 		"  colima start --arch aarch64\n" +
 		"  colima start --dns 1.1.1.1 --dns 8.8.8.8\n" +
 		"  colima start --dns-host example.com=1.2.3.4\n" +
-		"  colima start --kubernetes --k3s-arg=\"--disable=coredns,servicelb,traefik,local-storage,metrics-server\"",
+		"  colima start --kubernetes --k3s-arg='\"--disable=coredns,servicelb,traefik,local-storage,metrics-server\"'",
 	Args: cobra.MaximumNArgs(1),
 	RunE: func(cmd *cobra.Command, args []string) error {
 		app := newApp()
@@ -112,6 +112,7 @@ const (
 	defaultCPU               = 2
 	defaultMemory            = 2
 	defaultDisk              = 100
+	defaultRootDisk          = 20
 	defaultKubernetesVersion = kubernetes.DefaultVersion
 
 	defaultMountTypeQEMU = "sshfs"
@@ -163,16 +164,20 @@ func init() {
 
 	root.Cmd().AddCommand(startCmd)
 	startCmd.Flags().StringVarP(&startCmdArgs.Runtime, "runtime", "r", docker.Name, "container runtime ("+runtimes+")")
-	startCmd.Flags().BoolVar(&startCmdArgs.Flags.ActivateRuntime, "activate", true, "set as active Docker/Kubernetes context on startup")
+	startCmd.Flags().BoolVar(&startCmdArgs.Flags.ActivateRuntime, "activate", true, "set as active Docker/Kubernetes/Incus context on startup")
 	startCmd.Flags().IntVarP(&startCmdArgs.CPU, "cpus", "c", defaultCPU, "number of CPUs")
 	startCmd.Flags().StringVar(&startCmdArgs.CPUType, "cpu-type", "", "the CPU type, options can be checked with 'qemu-system-"+defaultArch+" -cpu help'")
 	startCmd.Flags().Float32VarP(&startCmdArgs.Memory, "memory", "m", defaultMemory, "memory in GiB")
 	startCmd.Flags().IntVarP(&startCmdArgs.Disk, "disk", "d", defaultDisk, "disk size in GiB")
+	startCmd.Flags().IntVar(&startCmdArgs.RootDisk, "root-disk", defaultRootDisk, "disk size in GiB for the root filesystem")
 	startCmd.Flags().StringVarP(&startCmdArgs.Arch, "arch", "a", defaultArch, "architecture (aarch64, x86_64)")
 	startCmd.Flags().BoolVarP(&startCmdArgs.Flags.Foreground, "foreground", "f", false, "Keep colima in the foreground")
 	startCmd.Flags().StringVar(&startCmdArgs.Hostname, "hostname", "", "custom hostname for the virtual machine")
 	startCmd.Flags().StringVarP(&startCmdArgs.DiskImage, "disk-image", "i", "", "file path to a custom disk image")
-	startCmd.Flags().BoolVar(&startCmdArgs.Flags.Template, "template", false, "use the template file for initial configuration")
+	startCmd.Flags().BoolVar(&startCmdArgs.Flags.Template, "template", true, "use the template file for initial configuration")
+
+	// port forwarder
+	startCmd.Flags().StringVar(&startCmdArgs.PortForwarder, "port-forwarder", "ssh", "port forwarder to use (ssh, grpc)")
 
 	// retain cpu flag for backward compatibility
 	startCmd.Flags().IntVar(&startCmdArgs.Flags.LegacyCPU, "cpu", defaultCPU, "number of CPUs")
@@ -186,6 +191,9 @@ func init() {
 	if util.MacOS() {
 		// network address
 		startCmd.Flags().BoolVar(&startCmdArgs.Network.Address, "network-address", false, "assign reachable IP address to the VM")
+		startCmd.Flags().StringVar(&startCmdArgs.Network.Mode, "network-mode", "shared", "network mode (shared, bridged)")
+		startCmd.Flags().StringVar(&startCmdArgs.Network.BridgeInterface, "network-interface", "en0", "host network interface to use for bridged mode")
+		startCmd.Flags().BoolVar(&startCmdArgs.Network.PreferredRoute, "network-preferred-route", false, "use the assigned IP address as the preferred route for the VM (implies --network-address)")
 
 		// vm type
 		if util.MacOS13OrNewer() {
@@ -226,6 +234,7 @@ func init() {
 	startCmd.Flags().StringVar(&startCmdArgs.Kubernetes.Version, "kubernetes-version", defaultKubernetesVersion, "must match a k3s version https://github.com/k3s-io/k3s/releases")
 	startCmd.Flags().StringSliceVar(&startCmdArgs.Flags.LegacyKubernetesDisable, "kubernetes-disable", nil, "components to disable for k3s e.g. traefik,servicelb")
 	startCmd.Flags().StringSliceVar(&startCmdArgs.Kubernetes.K3sArgs, "k3s-arg", defaultK3sArgs, "additional args to pass to k3s")
+	startCmd.Flags().IntVar(&startCmdArgs.Kubernetes.Port, "k3s-listen-port", 0, "k3s server listen port")
 	startCmd.Flag("with-kubernetes").Hidden = true
 	startCmd.Flag("kubernetes-disable").Hidden = true
 
@@ -338,6 +347,10 @@ func setConfigDefaults(conf *config.Config) {
 	if conf.Hostname == "" {
 		conf.Hostname = config.CurrentProfile().ID
 	}
+
+	if conf.PortForwarder == "" {
+		conf.PortForwarder = "ssh"
+	}
 }
 
 func setFixedConfigs(conf *config.Config) {
@@ -374,6 +387,10 @@ func setFixedConfigs(conf *config.Config) {
 		log.Warnln("network address cannot be disabled once enabled")
 		conf.Network.Address = true
 	}
+	if fixedConf.Network.Mode != "" {
+		warnIfNotEqual("network mode", conf.Network.Mode, fixedConf.Network.Mode)
+		conf.Network.Mode = fixedConf.Network.Mode
+	}
 }
 
 func prepareConfig(cmd *cobra.Command) {
@@ -445,6 +462,11 @@ func prepareConfig(cmd *cobra.Command) {
 	if !cmd.Flag("disk").Changed {
 		startCmdArgs.Disk = current.Disk
 	}
+	if !cmd.Flag("root-disk").Changed {
+		if current.RootDisk > 0 {
+			startCmdArgs.RootDisk = current.RootDisk
+		}
+	}
 	if !cmd.Flag("kubernetes").Changed {
 		startCmdArgs.Kubernetes.Enabled = current.Kubernetes.Enabled
 	}
@@ -454,6 +476,9 @@ func prepareConfig(cmd *cobra.Command) {
 	if !cmd.Flag("k3s-arg").Changed && current.Kubernetes.K3sArgs != nil {
 		startCmdArgs.Kubernetes.K3sArgs = current.Kubernetes.K3sArgs
 	}
+	if !cmd.Flag("k3s-listen-port").Changed && current.Kubernetes.Port > 0 {
+		startCmdArgs.Kubernetes.Port = current.Kubernetes.Port
+	}
 	if !cmd.Flag("runtime").Changed {
 		startCmdArgs.Runtime = current.Runtime
 	}
@@ -484,6 +509,9 @@ func prepareConfig(cmd *cobra.Command) {
 	if !cmd.Flag("ssh-port").Changed {
 		startCmdArgs.SSHPort = current.SSHPort
 	}
+	if !cmd.Flag("port-forwarder").Changed {
+		startCmdArgs.PortForwarder = current.PortForwarder
+	}
 	if !cmd.Flag("dns").Changed {
 		startCmdArgs.Network.DNSResolvers = current.Network.DNSResolvers
 	}
@@ -513,6 +541,15 @@ func prepareConfig(cmd *cobra.Command) {
 		if !cmd.Flag("network-address").Changed {
 			startCmdArgs.Network.Address = current.Network.Address
 		}
+		if !cmd.Flag("network-mode").Changed {
+			startCmdArgs.Network.Mode = current.Network.Mode
+		}
+		if !cmd.Flag("network-interface").Changed {
+			startCmdArgs.Network.BridgeInterface = current.Network.BridgeInterface
+		}
+		if !cmd.Flag("network-preferred-route").Changed {
+			startCmdArgs.Network.PreferredRoute = current.Network.PreferredRoute
+		}
 		if util.MacOS13OrNewer() {
 			if !cmd.Flag("vm-type").Changed {
 				startCmdArgs.VMType = current.VMType
