@@ -1,8 +1,8 @@
 package config
 
 import (
+	"fmt"
 	"net"
-	"path/filepath"
 
 	"github.com/abiosoft/colima/util"
 	"github.com/abiosoft/colima/util/osutil"
@@ -31,6 +31,7 @@ var (
 type Config struct {
 	CPU      int               `yaml:"cpu,omitempty"`
 	Disk     int               `yaml:"disk,omitempty"`
+	RootDisk int               `yaml:"rootDisk,omitempty"`
 	Memory   float32           `yaml:"memory,omitempty"`
 	Arch     string            `yaml:"arch,omitempty"`
 	CPUType  string            `yaml:"cpuType,omitempty"`
@@ -49,6 +50,7 @@ type Config struct {
 	Binfmt               *bool  `yaml:"binfmt,omitempty"`
 	NestedVirtualization bool   `yaml:"nestedVirtualization,omitempty"`
 	DiskImage            string `yaml:"diskImage,omitempty"`
+	PortForwarder        string `yaml:"portForwarder,omitempty"` // "ssh", "grpc"
 
 	// volume mounts
 	Mounts       []Mount `yaml:"mounts,omitempty"`
@@ -74,14 +76,18 @@ type Kubernetes struct {
 	Enabled bool     `yaml:"enabled"`
 	Version string   `yaml:"version"`
 	K3sArgs []string `yaml:"k3sArgs"`
+	Port    int      `yaml:"port,omitempty"`
 }
 
 // Network is VM network configuration
 type Network struct {
-	Address       bool              `yaml:"address"`
-	DNSResolvers  []net.IP          `yaml:"dns"`
-	DNSHosts      map[string]string `yaml:"dnsHosts"`
-	HostAddresses bool              `yaml:"hostAddresses"`
+	Address         bool              `yaml:"address"`
+	DNSResolvers    []net.IP          `yaml:"dns"`
+	DNSHosts        map[string]string `yaml:"dnsHosts"`
+	HostAddresses   bool              `yaml:"hostAddresses"`
+	Mode            string            `yaml:"mode"` // shared, bridged
+	BridgeInterface string            `yaml:"interface"`
+	PreferredRoute  bool              `yaml:"preferredRoute"`
 }
 
 // Mount is volume mount
@@ -103,7 +109,6 @@ func (c Config) MountsOrDefault() []Mount {
 
 	return []Mount{
 		{Location: util.HomeDir(), Writable: true},
-		{Location: filepath.Join("/tmp", CurrentProfile().ID), Writable: true},
 	}
 }
 
@@ -125,6 +130,15 @@ func (c Config) DriverLabel() string {
 	return "QEMU"
 }
 
+// Disk is an instance disk size
+type Disk int
+
+// GiB returns the string represent of the disk in GiB.
+func (d Disk) GiB() string { return fmt.Sprintf("%dGiB", d) }
+
+// Int returns the disk size in bytes.
+func (d Disk) Int() int64 { return 1024 * 1024 * 1024 * int64(d) }
+
 // CtxKey returns the context key for config.
 func CtxKey() any {
 	return struct{ name string }{name: "colima_config"}
