@@ -76,10 +76,8 @@ func (d dockerRuntime) Provision(ctx context.Context) error {
 func (d dockerRuntime) Start(ctx context.Context) error {
 	a := d.Init(ctx)
 
-	// TODO: interval is high due to 0.6.3->0.6.4 docker-ce package transition
-	//       to ensure startup is successful
-	a.Retry("", time.Second, 120, func(int) error {
-		return d.guest.RunQuiet("sudo", "service", "docker", "start")
+	a.Retry("", time.Second, 60, func(int) error {
+		return d.guest.RunQuiet("sudo", "systemctl", "start", "docker.service")
 	})
 
 	// service startup takes few seconds, retry for a minute before giving up.
@@ -111,7 +109,7 @@ func (d dockerRuntime) Stop(ctx context.Context) error {
 		if !d.Running(ctx) {
 			return nil
 		}
-		return d.guest.Run("sudo", "service", "docker", "stop")
+		return d.guest.Run("sudo", "systemctl", "stop", "docker.service")
 	})
 
 	// clear docker context settings
@@ -149,3 +147,22 @@ func (d *dockerRuntime) Update(ctx context.Context) (bool, error) {
 
 	return debutil.UpdateRuntime(ctx, d.guest, d, packages...)
 }
+
+// DataDirs represents the data disk for the container runtime.
+func DataDisk() environment.DataDisk {
+	return environment.DataDisk{
+		Dirs:   diskDirs,
+		FSType: "ext4",
+		PreMount: []string{
+			"systemctl stop docker.service",
+			"systemctl stop containerd.service",
+		},
+	}
+}
+
+var diskDirs = []environment.DiskDir{
+	{Name: "docker", Path: "/var/lib/docker"},
+	{Name: "containerd", Path: "/var/lib/containerd"},
+	{Name: "rancher", Path: "/var/lib/rancher"},
+	{Name: "cni", Path: "/var/lib/cni"},
+}
