@@ -32,7 +32,17 @@ var configDir = func() string { return config.CurrentProfile().ConfigDir() }
 // HostSocketFile returns the path to the containerd socket on host.
 func HostSocketFile() string { return filepath.Join(configDir(), "incus.sock") }
 
-const Name = "incus"
+const (
+	Name = "incus"
+
+	storageDriver = "zfs"
+
+	poolName    = "default"
+	poolMetaDir = "/var/lib/incus/storage-pools/" + poolName
+
+	poolDisksDir = "/var/lib/incus/disks"
+	poolDiskFile = poolDisksDir + "/" + poolName + ".img"
+)
 
 func init() {
 	environment.RegisterContainer(Name, newRuntime, false)
@@ -53,19 +63,31 @@ func (c *incusRuntime) Dependencies() []string {
 
 // Provision implements environment.Container.
 func (c *incusRuntime) Provision(ctx context.Context) error {
-	conf, _ := ctx.Value(config.CtxKey()).(config.Config)
+	conf := ctx.Value(config.CtxKey()).(config.Config)
+	log := c.Logger(ctx)
 
-	if err := c.guest.RunQuiet("ip", "addr", "show", incusBridgeInterface); err == nil {
+	if found, _, _ := c.findNetwork(incusBridgeInterface); found {
 		// already provisioned
 		return nil
 	}
 
-	var value struct {
-		Disk      int
-		Interface string
+	emptyDisk := true
+	recoverStorage := false
+	if limautil.DiskProvisioned(Name) {
+		emptyDisk = false
+		// previous disk exists
+		// ignore storage, recovery would be attempted later
+		recoverStorage = cli.Prompt("existing Incus data found, would you like to recover the storage pool(s)")
 	}
-	value.Disk = conf.Disk - 5 // use all disk except 5GiB. TODO: revisit.
+
+	var value struct {
+		Disk       int
+		Interface  string
+		SetStorage bool
+	}
+	value.Disk = conf.Disk
 	value.Interface = incusBridgeInterface
+	value.SetStorage = emptyDisk // set only when the disk is empty
 
 	buf, err := util.ParseTemplate(configYaml, value)
 	if err != nil {
@@ -77,6 +99,34 @@ func (c *incusRuntime) Provision(ctx context.Context) error {
 		return fmt.Errorf("error setting up incus: %w", err)
 	}
 
+	// provision successful
+	if emptyDisk {
+		return nil
+	}
+
+	if !recoverStorage {
+		return c.wipeDisk(conf.Disk)
+	}
+
+	if _, err := c.guest.Stat(poolDiskFile); err != nil {
+		log.Warnln(fmt.Errorf("cannot recover disk: %w, creating new storage pool", err))
+		return c.wipeDisk(conf.Disk)
+	}
+
+	for {
+		if err := c.recoverDisk(ctx); err != nil {
+			log.Warnln(err)
+
+			if cli.Prompt("recovery failed for default storage pool, try again") {
+				continue
+			}
+
+			log.Warnln("discarding disk, creating new storage pool")
+			return c.wipeDisk(conf.Disk)
+		}
+		break
+	}
+
 	return nil
 }
 
@@ -91,9 +141,29 @@ func (c *incusRuntime) Start(ctx context.Context) error {
 
 	a := c.Init(ctx)
 
-	a.Add(func() error {
-		return c.guest.RunQuiet("sudo", "service", "incus", "start")
-	})
+	// incus should already be started
+	// this is mainly to ascertain it has started
+
+	if c.poolImported() {
+		a.Add(func() error {
+			return c.guest.RunQuiet("sudo", "systemctl", "start", "incus.service")
+		})
+	} else {
+		// pool not yet imported
+		// restart incus to import pool
+		a.Add(func() error {
+			return c.guest.RunQuiet("sudo", "systemctl", "restart", "incus.service")
+		})
+	}
+
+	// sync disk size for the default pool
+	if conf.Disk > 0 {
+		a.Add(func() error {
+			// this can fail silently
+			_ = c.guest.RunQuiet("sudo", "incus", "storage", "set", "default", "size="+config.Disk(conf.Disk).GiB())
+			return nil
+		})
+	}
 
 	a.Add(func() error {
 		// attempt to set remote
@@ -233,25 +303,11 @@ func (c incusRuntime) addDockerRemote() error {
 }
 
 func (c incusRuntime) registerNetworks() error {
-	b, err := c.guest.RunOutput("sudo", "incus", "network", "list", "--format", "json")
-	if err != nil {
-		return fmt.Errorf("error listing networks: %w", err)
-	}
-
-	var network networkInfo
-	var found bool
 	name := limautil.NetInterface
-	{ // decode and flatten for easy lookup
-		var resp []networkInfo
-		if err := json.NewDecoder(strings.NewReader(b)).Decode(&resp); err != nil {
-			return fmt.Errorf("error decoding networks into struct: %w", err)
-		}
-		for _, n := range resp {
-			if n.Name == name {
-				network = n
-				found = true
-			}
-		}
+
+	found, network, err := c.findNetwork(name)
+	if err != nil {
+		return err
 	}
 
 	// must be an unmanaged physical network
@@ -267,6 +323,24 @@ func (c incusRuntime) registerNetworks() error {
 	return nil
 }
 
+func (c incusRuntime) findNetwork(interfaceName string) (found bool, info networkInfo, err error) {
+	b, err := c.guest.RunOutput("sudo", "incus", "network", "list", "--format", "json")
+	if err != nil {
+		return found, info, fmt.Errorf("error listing networks: %w", err)
+	}
+	var resp []networkInfo
+	if err := json.NewDecoder(strings.NewReader(b)).Decode(&resp); err != nil {
+		return found, info, fmt.Errorf("error decoding networks into struct: %w", err)
+	}
+	for _, n := range resp {
+		if n.Name == interfaceName {
+			return true, n, nil
+		}
+	}
+
+	return
+}
+
 //go:embed config.yaml
 var configYaml string
 
@@ -291,3 +365,76 @@ func (c *incusRuntime) Update(ctx context.Context) (bool, error) {
 
 	return debutil.UpdateRuntime(ctx, c.guest, c, packages...)
 }
+
+func (c *incusRuntime) poolImported() bool {
+	script := strings.NewReplacer(
+		"{pool_name}", poolName,
+	).Replace("sudo zpool list -H -o name | grep '^{pool_name}$'")
+	return c.guest.RunQuiet("sh", "-c", script) == nil
+}
+
+func (c *incusRuntime) recoverDisk(ctx context.Context) error {
+	var disks []string
+	str, err := c.guest.RunOutput("sh", "-c", "sudo ls "+poolDisksDir+" | grep '.img$'")
+
+	if err != nil {
+		return fmt.Errorf("cannot list storage pool disks: %w", err)
+	}
+
+	disks = strings.Fields(str)
+	if len(disks) == 0 {
+		return fmt.Errorf("no existing storage pool disks found")
+	}
+
+	log := c.Logger(ctx)
+
+	log.Println()
+	log.Println("Running 'incus admin recover' ...")
+	log.Println()
+	log.Println(fmt.Sprintf("Found %d storage pool source(s):", len(disks)))
+	for _, disk := range disks {
+		log.Println("  " + poolDisksDir + "/" + disk)
+	}
+	log.Println()
+
+	if err := c.guest.RunInteractive("sudo", "incus", "admin", "recover"); err != nil {
+		return fmt.Errorf("error recovering storage pool: %w", err)
+	}
+
+	out, err := c.guest.RunOutput("sudo", "incus", "storage", "list", "name="+poolName, "-c", "n", "--format", "compact,noheader")
+	if err != nil {
+		return err
+	}
+
+	if out != poolName {
+		return fmt.Errorf("default storage pool recovery failure")
+	}
+
+	return nil
+}
+
+func (c *incusRuntime) wipeDisk(size int) error {
+	// prepare by deleting relevant files/directories
+	deleteScript := strings.NewReplacer(
+		"{disk_file}", poolDiskFile,
+		"{meta_dir}", poolMetaDir,
+	).Replace("sudo rm -rf {disk_file} {meta_dir}")
+
+	if err := c.guest.RunQuiet("sh", "-c", deleteScript); err != nil {
+		return fmt.Errorf("error preparing storage pools directory: %w", err)
+	}
+
+	// create new storage pool
+	var diskSize = fmt.Sprintf("%dGiB", size)
+	return c.guest.RunQuiet("sudo", "incus", "storage", "create", poolName, storageDriver, "size="+diskSize)
+}
+
+// DataDirs represents the data disk for the container runtime.
+func DataDisk() environment.DataDisk {
+	return environment.DataDisk{
+		FSType: "ext4",
+		Dirs: []environment.DiskDir{
+			{Name: "incus-disks", Path: "/var/lib/incus/disks"},
+		},
+	}
+}
