@@ -4,6 +4,7 @@ import (
 	"fmt"
 	"strconv"
 	"strings"
+	"time"
 
 	"github.com/abiosoft/colima/cli"
 	"github.com/abiosoft/colima/config"
@@ -39,11 +40,12 @@ func installK3s(host environment.HostActions,
 	log *logrus.Entry,
 	containerRuntime string,
 	k3sVersion string,
-	disable []string,
+	k3sArgs []string,
+	k3sListenPort int,
 ) {
 	installK3sBinary(host, guest, a, k3sVersion)
 	installK3sCache(host, guest, a, log, containerRuntime, k3sVersion)
-	installK3sCluster(host, guest, a, containerRuntime, k3sVersion, disable)
+	installK3sCluster(host, guest, a, containerRuntime, k3sVersion, k3sArgs, k3sListenPort)
 }
 
 func installK3sBinary(
@@ -140,6 +142,7 @@ func installK3sCluster(
 	containerRuntime string,
 	k3sVersion string,
 	k3sArgs []string,
+	k3sListenPort int,
 ) {
 	// install k3s last to ensure it is the last step
 	downloadPath := "/tmp/k3s-install.sh"
@@ -156,18 +159,24 @@ func installK3sCluster(
 		"--write-kubeconfig-mode", "644",
 	}, k3sArgs...)
 
-	// replace ip address if networking is enabled
-	ipAddress := limautil.IPAddress(config.CurrentProfile().ID)
-	if ipAddress == "127.0.0.1" {
-		args = append(args, "--flannel-iface", "eth0")
-	} else {
-		if !hasK3sArg(k3sArgs, "--advertise-address") {
-			args = append(args, "--advertise-address", ipAddress)
+	a.Retry("waiting for VM IP address", time.Second*5, 4, func(retryCount int) error {
+		ipAddress := limautil.IPAddress(config.CurrentProfile().ID)
+		if ipAddress == "" {
+			return fmt.Errorf("no IP address assigned to network interface")
 		}
-		if !hasK3sArg(k3sArgs, "--flannel-iface") {
-			args = append(args, "--flannel-iface", limautil.NetInterface)
+
+		if ipAddress == "127.0.0.1" {
+			args = append(args, "--flannel-iface", "eth0")
+		} else {
+			if !hasK3sArg(k3sArgs, "--advertise-address") {
+				args = append(args, "--advertise-address", ipAddress)
+			}
+			if !hasK3sArg(k3sArgs, "--flannel-iface") {
+				args = append(args, "--flannel-iface", limautil.NetInterface)
+			}
 		}
-	}
+		return nil
+	})
 
 	switch containerRuntime {
 	case docker.Name:
@@ -177,7 +186,7 @@ func installK3sCluster(
 	}
 
 	a.Add(func() error {
-		port, err := getPortNumber(guest)
+		port, err := getPortNumber(guest, k3sListenPort)
 		if err != nil {
 			return err
 		}
@@ -192,7 +201,7 @@ func installK3sCluster(
 
 // getPortNumber retrieves the previously set port number.
 // If missing, an available random port is set and return.
-func getPortNumber(guest environment.GuestActions) (int, error) {
+func getPortNumber(guest environment.GuestActions, k3sListenPort int) (int, error) {
 	// port previously set, reuse it
 	if port, err := strconv.Atoi(guest.Get(listenPortKey)); err == nil && port > 0 {
 		return port, nil
@@ -204,8 +213,15 @@ func getPortNumber(guest environment.GuestActions) (int, error) {
 		return 6443, nil
 	}
 
-	// new instance, assign random port
-	port := util.RandomAvailablePort()
+	var port int
+	if k3sListenPort > 0 {
+		// template configured port
+		port = k3sListenPort
+	} else {
+		// new instance, assign random port
+		port = util.RandomAvailablePort()
+	}
+
 	if err := guest.Set(listenPortKey, strconv.Itoa(port)); err != nil {
 		return 0, err
 	}
