@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"strconv"
 	"time"
 
 	"github.com/abiosoft/colima/cli"
@@ -15,12 +16,11 @@ import (
 	"github.com/abiosoft/colima/environment"
 	"github.com/abiosoft/colima/environment/vm/lima/limaconfig"
 	"github.com/abiosoft/colima/environment/vm/lima/limautil"
+	"github.com/abiosoft/colima/store"
 	"github.com/abiosoft/colima/util"
-	"github.com/abiosoft/colima/util/downloader"
 	"github.com/abiosoft/colima/util/osutil"
 	"github.com/abiosoft/colima/util/yamlutil"
 	"github.com/sirupsen/logrus"
-	yaml "gopkg.in/yaml.v3"
 )
 
 // New creates a new virtual machine.
@@ -78,6 +78,8 @@ func (l limaVM) Dependencies() []string {
 func (l *limaVM) Start(ctx context.Context, conf config.Config) error {
 	a := l.Init(ctx)
 
+	l.prepareHost(conf)
+
 	if l.Created() {
 		return l.resume(ctx, conf)
 	}
@@ -97,6 +99,10 @@ func (l *limaVM) Start(ctx context.Context, conf config.Config) error {
 
 	a.Add(l.assertQemu)
 
+	a.Add(func() error {
+		return l.createRuntimeDisk(conf)
+	})
+
 	a.Add(func() error {
 		return l.downloadDiskImage(ctx, conf)
 	})
@@ -148,6 +154,11 @@ func (l *limaVM) resume(ctx context.Context, conf config.Config) error {
 
 	a.Add(l.assertQemu)
 
+	a.Add(func() error {
+		l.useRuntimeDisk(conf)
+		return nil
+	})
+
 	a.Add(l.setDiskImage)
 
 	a.Add(func() error {
@@ -271,140 +282,43 @@ func (l limaVM) Arch() environment.Arch {
 	return environment.Arch(a)
 }
 
-func (l *limaVM) downloadDiskImage(ctx context.Context, conf config.Config) error {
-	log := l.Logger(ctx)
-
-	// use a user specified disk image
-	if conf.DiskImage != "" {
-		if _, err := os.Stat(conf.DiskImage); err != nil {
-			return fmt.Errorf("invalid disk image: %w", err)
-		}
-
-		image, err := limautil.Image(l.limaConf.Arch, conf.Runtime)
-		if err != nil {
-			return fmt.Errorf("error getting disk image details: %w", err)
-		}
-
-		sha := downloader.SHA{Size: 512, Digest: image.Digest}
-		if err := sha.ValidateFile(l.host, conf.DiskImage); err != nil {
-			return fmt.Errorf("disk image must be downloaded from '%s', hash failure: %w", image.Location, err)
-		}
-
-		image.Location = conf.DiskImage
-		l.limaConf.Images = []limaconfig.File{image}
-		return nil
-	}
-
-	// use a previously cached image
-	if image, ok := limautil.ImageCached(l.limaConf.Arch, conf.Runtime); ok {
-		l.limaConf.Images = []limaconfig.File{image}
-		return nil
-	}
-
-	// download image
-	log.Infoln("downloading disk image ...")
-	image, err := limautil.DownloadImage(l.limaConf.Arch, conf.Runtime)
-	if err != nil {
-		return fmt.Errorf("error getting qcow image: %w", err)
-	}
-
-	l.limaConf.Images = []limaconfig.File{image}
-	return nil
-}
-
-func (l *limaVM) setDiskImage() error {
-	var c limaconfig.Config
-	b, err := os.ReadFile(config.CurrentProfile().LimaFile())
-	if err != nil {
-		return err
-	}
-	if err := yaml.Unmarshal(b, &c); err != nil {
-		return err
-	}
-
-	l.limaConf.Images = c.Images
-	return nil
-}
-
-func (l *limaVM) syncDiskSize(ctx context.Context, conf config.Config) config.Config {
-	log := l.Logger(ctx)
-	instance, err := configmanager.LoadInstance()
-	if err != nil {
-		// instance config missing, ignore
-		return conf
-	}
-
-	resized := func() bool {
-		if instance.Disk == conf.Disk {
-			// nothing to do
-			return false
-		}
-
-		size := conf.Disk - instance.Disk
-		if size < 0 {
-			log.Warnln("disk size cannot be reduced, ignoring...")
-			return false
-		}
-
-		if err := util.AssertQemuImg(); err != nil {
-			log.Warnln(fmt.Errorf("unable to resize disk: %w", err))
-			return false
-		}
-
-		sizeStr := fmt.Sprintf("%dG", conf.Disk)
-		args := []string{"qemu-img", "resize"}
-		disk := limautil.ColimaDiffDisk(config.CurrentProfile().ID)
-		args = append(args, disk, sizeStr)
-
-		// qemu-img resize /path/to/diffdisk +10G
-		if err := l.host.RunQuiet(args...); err != nil {
-			log.Warnln(fmt.Errorf("unable to resize disk: %w", err))
-			return false
-		}
-
-		log.Printf("resizing disk to %dGiB...", conf.Disk)
-		return true
-	}()
-
-	if !resized {
-		conf.Disk = instance.Disk
-	}
-
-	return conf
-}
-
 func (l *limaVM) addPostStartActions(a *cli.ActiveCommandChain, conf config.Config) {
+	// setup dns
+	a.Add(func() error {
+		if err := l.setupDNS(conf); err != nil {
+			return fmt.Errorf("error setting up DNS: %w", err)
+		}
+		return nil
+	})
+
 	// registry certs
 	a.Add(l.copyCerts)
 
 	// cross-platform emulation
 	a.Add(func() error {
-		if !l.limaConf.Rosetta.Enabled {
-			// use binfmt when rosetta is disabled and emulation is disabled i.e. host arch
-			if conf.Binfmt != nil && *conf.Binfmt {
-				if arch := environment.HostArch(); arch == environment.Arch(conf.Arch).Value() {
-					if err := core.SetupBinfmt(l.host, l, environment.Arch(conf.Arch)); err != nil {
-						logrus.Warn(fmt.Errorf("unable to enable qemu %s emulation: %w", arch, err))
-					}
+		// use binfmt when emulation is disabled i.e. host arch
+		if conf.Binfmt != nil && *conf.Binfmt {
+			if arch := environment.HostArch(); arch == environment.Arch(conf.Arch).Value() {
+				if err := core.SetupBinfmt(l.host, l, environment.Arch(conf.Arch)); err != nil {
+					logrus.Warn(fmt.Errorf("unable to enable qemu %s emulation: %w", arch, err))
 				}
 			}
-
-			// rosetta is disabled
-			return nil
 		}
 
-		// enable rosetta
-		err := l.Run("sudo", "sh", "-c", `stat /proc/sys/fs/binfmt_misc/rosetta || echo ':rosetta:M::\x7fELF\x02\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x3e\x00:\xff\xff\xff\xff\xff\xfe\xfe\x00\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xff\xff\xff:/mnt/lima-rosetta/rosetta:OCF' > /proc/sys/fs/binfmt_misc/register`)
-		if err != nil {
-			logrus.Warn(fmt.Errorf("unable to enable rosetta: %w", err))
-			return nil
-		}
-
-		// disable qemu
-		if err := l.RunQuiet("stat", "/proc/sys/fs/binfmt_misc/qemu-x86_64"); err == nil {
-			err = l.Run("sudo", "sh", "-c", `echo 0 > /proc/sys/fs/binfmt_misc/qemu-x86_64`)
+		if l.limaConf.Rosetta.Enabled {
+			// enable rosetta
+			err := l.Run("sudo", "sh", "-c", `stat /proc/sys/fs/binfmt_misc/rosetta || echo ':rosetta:M::\x7fELF\x02\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x3e\x00:\xff\xff\xff\xff\xff\xfe\xfe\x00\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xff\xff\xff:/mnt/lima-rosetta/rosetta:OCF' > /proc/sys/fs/binfmt_misc/register`)
 			if err != nil {
-				logrus.Warn(fmt.Errorf("unable to disable qemu x86_84 emulation: %w", err))
+				logrus.Warn(fmt.Errorf("unable to enable rosetta: %w", err))
+				return nil
+			}
+
+			// disable qemu
+			if err := l.RunQuiet("stat", "/proc/sys/fs/binfmt_misc/qemu-x86_64"); err == nil {
+				err = l.Run("sudo", "sh", "-c", `echo 0 > /proc/sys/fs/binfmt_misc/qemu-x86_64`)
+				if err != nil {
+					logrus.Warn(fmt.Errorf("unable to disable qemu x86_84 emulation: %w", err))
+				}
 			}
 		}
 
@@ -426,6 +340,25 @@ func (l *limaVM) addPostStartActions(a *cli.ActiveCommandChain, conf config.Conf
 		}
 		return nil
 	})
+
+	// save store settings
+	a.Add(func() error {
+		if len(l.limaConf.AdditionalDisks) == 0 {
+			return nil
+		}
+
+		// startup is successful
+		// if additional disk is present, then it must've been formatted correctly.
+		if err := store.Set(func(s *store.Store) {
+			s.DiskFormatted = true
+		}); err != nil {
+			// not fatal, but should be logged
+			logrus.Warnln(fmt.Errorf("error persisting store settings: %w", err))
+		}
+
+		return nil
+	})
+
 }
 
 func (l *limaVM) assertQemu() error {
@@ -439,3 +372,11 @@ func (l *limaVM) assertQemu() error {
 	}
 	return nil
 }
+
+const envLimaSSHPortForwarder = "LIMA_SSH_PORT_FORWARDER"
+
+func (l *limaVM) prepareHost(conf config.Config) {
+	useSSHPortForwarder := conf.PortForwarder != "grpc"
+
+	l.host = l.host.WithEnv(envLimaSSHPortForwarder + "=" + strconv.FormatBool(useSSHPortForwarder))
+}
