@@ -9,7 +9,8 @@ import (
 const NetInterface = "col0"
 
 // network metric for the route
-const NetMetric = 300
+const NetMetric uint32 = 300
+const NetMetricPreferred uint32 = 100
 
 // IPAddress returns the ip address for profile.
 // It returns the PTP address if networking is enabled or falls back to 127.0.0.1.
@@ -34,6 +35,11 @@ func IPAddress(profileID string) string {
 	return fallback
 }
 
+// InternalIPAddress returns the internal IP address for the profile.
+func InternalIPAddress(profileID string) string {
+	return getIPAddress(profileID, "eth0")
+}
+
 func getIPAddress(profileID, interfaceName string) string {
 	var buf bytes.Buffer
 	// TODO: this should be less hacky
