@@ -5,7 +5,6 @@ import (
 	"fmt"
 	"net"
 	"os"
-	"path/filepath"
 	"strings"
 
 	"github.com/abiosoft/colima/daemon"
@@ -62,8 +61,8 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 	if conf.Memory > 0 {
 		l.Memory = fmt.Sprintf("%dMiB", uint32(conf.Memory*1024))
 	}
-	if conf.Disk > 0 {
-		l.Disk = fmt.Sprintf("%dGiB", conf.Disk)
+	if conf.RootDisk > 0 {
+		l.Disk = fmt.Sprintf("%dGiB", conf.RootDisk)
 	}
 	l.SSH = limaconfig.SSH{LocalPort: conf.SSHPort, LoadDotSSHPubKeys: false, ForwardAgent: conf.ForwardAgent}
 	l.Containerd = limaconfig.Containerd{System: false, User: false}
@@ -115,6 +114,10 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 		if conf.Hostname != "" {
 			hostname = conf.Hostname
 		}
+		l.Provision = append(l.Provision, limaconfig.Provision{
+			Mode:   limaconfig.ProvisionModeSystem,
+			Script: "grep '127.0.0.1 " + hostname + "' /etc/hosts || echo '127.0.0.1 " + hostname + "' >> /etc/hosts",
+		})
 		l.Provision = append(l.Provision, limaconfig.Provision{
 			Mode:   limaconfig.ProvisionModeSystem,
 			Script: "hostnamectl set-hostname " + hostname,
@@ -130,12 +133,16 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 
 		reachableIPAddress := true
 		if conf.Network.Address {
-			// incus always uses vmnet
-			if l.VMType == limaconfig.VZ && conf.Runtime != incus.Name {
+			metric := limautil.NetMetric
+			if conf.Network.PreferredRoute {
+				metric = limautil.NetMetricPreferred
+			}
+			// vmnet is always used for incus runtime or bridged mode
+			if l.VMType == limaconfig.VZ && conf.Runtime != incus.Name && conf.Network.Mode != "bridged" {
 				l.Networks = append(l.Networks, limaconfig.Network{
 					VZNAT:     true,
 					Interface: limautil.NetInterface,
-					Metric:    limautil.NetMetric,
+					Metric:    metric,
 				})
 			} else {
 				reachableIPAddress, _ = ctx.Value(daemon.CtxKey(vmnet.Name)).(bool)
@@ -152,7 +159,7 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 						l.Networks = append(l.Networks, limaconfig.Network{
 							Socket:    socketFile,
 							Interface: limautil.NetInterface,
-							Metric:    limautil.NetMetric,
+							Metric:    metric,
 						})
 
 						return nil
@@ -168,14 +175,14 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 			if reachableIPAddress && conf.Kubernetes.Enabled && !ingressDisabled(conf.Kubernetes.K3sArgs) {
 				l.PortForwards = append(l.PortForwards,
 					limaconfig.PortForward{
-						GuestIP:           net.ParseIP("0.0.0.0"),
+						GuestIP:           net.IPv4zero,
 						GuestPort:         80,
 						GuestIPMustBeZero: true,
 						Ignore:            true,
 						Proto:             limaconfig.TCP,
 					},
 					limaconfig.PortForward{
-						GuestIP:           net.ParseIP("0.0.0.0"),
+						GuestIP:           net.IPv4zero,
 						GuestPort:         443,
 						GuestIPMustBeZero: true,
 						Ignore:            true,
@@ -188,7 +195,7 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 			if reachableIPAddress && conf.Runtime == incus.Name {
 				l.PortForwards = append(l.PortForwards,
 					limaconfig.PortForward{
-						GuestIP:           net.ParseIP("0.0.0.0"),
+						GuestIP:           net.IPv4zero,
 						GuestIPMustBeZero: true,
 						GuestPortRange:    [2]int{1, 65535},
 						HostPortRange:     [2]int{1, 65535},
@@ -263,17 +270,17 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 		l.PortForwards = append(l.PortForwards,
 			limaconfig.PortForward{
 				GuestIPMustBeZero: true,
-				GuestIP:           net.ParseIP("0.0.0.0"),
+				GuestIP:           net.IPv4zero,
 				GuestPortRange:    [2]int{1, 65535},
-				HostIP:            net.ParseIP("0.0.0.0"),
+				HostIP:            net.IPv4zero,
 				HostPortRange:     [2]int{1, 65535},
 				Proto:             limaconfig.TCP,
 			},
 			limaconfig.PortForward{
 				GuestIPMustBeZero: true,
-				GuestIP:           net.ParseIP("0.0.0.0"),
+				GuestIP:           net.IPv4zero,
 				GuestPortRange:    [2]int{1, 65535},
-				HostIP:            net.ParseIP("0.0.0.0"),
+				HostIP:            net.IPv4zero,
 				HostPortRange:     [2]int{1, 65535},
 				Proto:             limaconfig.UDP,
 			},
@@ -323,12 +330,18 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 		}
 	}
 
+	/*
+		provision scripts for disk actions
+	*/
+
+	// ensure all volumes are mounted.
 	l.Provision = append(l.Provision, limaconfig.Provision{
 		Mode:   limaconfig.ProvisionModeSystem,
 		Script: "mount -a",
 	})
 
 	// trim mounted drive to recover disk space
+	// however problematic for incus
 	if conf.Runtime != incus.Name {
 		l.Provision = append(l.Provision, limaconfig.Provision{
 			Mode:   limaconfig.ProvisionModeSystem,
@@ -336,10 +349,17 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 		})
 	}
 
+	// grow partition in case disk size has increased
+	l.Provision = append(l.Provision, limaconfig.Provision{
+		Mode:   limaconfig.ProvisionModeSystem,
+		Script: "resize2fs " + diskByLabelPath(config.CurrentProfile().ID) + " || true",
+	})
+
+	/* end */
+
 	if len(conf.Mounts) == 0 {
 		l.Mounts = append(l.Mounts,
 			limaconfig.Mount{Location: "~", Writable: true},
-			limaconfig.Mount{Location: filepath.Join("/tmp", config.CurrentProfile().ID), Writable: true},
 		)
 	} else {
 		// overlapping mounts are problematic in Lima https://github.com/lima-vm/lima/issues/302
@@ -387,19 +407,25 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 
 type Arch = environment.Arch
 
+func selectPath(m config.Mount) (string, error) {
+	if m.MountPoint != "" {
+		return util.CleanPath(m.MountPoint)
+	}
+
+	return util.CleanPath(m.Location)
+}
+
 func checkOverlappingMounts(mounts []config.Mount) error {
 	for i := 0; i < len(mounts)-1; i++ {
+		a, err := selectPath(mounts[i])
+		if err != nil {
+			return err
+		}
 		for j := i + 1; j < len(mounts); j++ {
-			a, err := util.CleanPath(mounts[i].Location)
+			b, err := selectPath(mounts[j])
 			if err != nil {
 				return err
 			}
-
-			b, err := util.CleanPath(mounts[j].Location)
-			if err != nil {
-				return err
-			}
-
 			if strings.HasPrefix(a, b) || strings.HasPrefix(b, a) {
 				return fmt.Errorf("'%s' overlaps '%s'", a, b)
 			}
@@ -431,3 +457,14 @@ func ingressDisabled(disableFlags []string) bool {
 	}
 	return false
 }
+
+const diskLabelMaxLength = 16 // https://tldp.org/HOWTO/Partition/labels.html
+
+func diskByLabelPath(instanceId string) string {
+	name := "lima-" + instanceId
+	if len(name) > diskLabelMaxLength {
+		name = name[:diskLabelMaxLength]
+	}
+
+	return "/dev/disk/by-label/" + name
+}
